This crate offers functions to get information about either the current or a specific keyboard layout from xkb, as well as to create maps between low level key identifiers (EVDEV/XKB) and the symbols xkb maps them to.
It is meant to be used in software that remaps input events or visualizes/configures keyboard layouts on Linux.
Modules
Structs
- KMError
- Simple Error type, which currently only contains a message.
- Key
- Description of a hardware key and what it’s mapped to.
- Keymap
- Structure containing all data queried from XKB about a layout. If multiple layouts are defined for switching, keys will list those of the first layout. Will contain all keys - even those not present on the current hardware devices.
- Mod
- A modifier from the list of modifiers.
- Symbol
- An associated symbol, e.g. the character to be typed or a special key like a modifier.